=====
phypy
=====


.. image:: https://img.shields.io/pypi/v/phypy.svg
        :target: https://pypi.python.org/pypi/phypy

.. image:: https://travis-ci.org/ctarver/phypy.svg?branch=master
        :target: https://travis-ci.org/ctarver/phypy

.. image:: https://readthedocs.org/projects/phypy/badge/?version=latest
        :target: https://phypy.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status




Library of tools for wireless, physical layer research, simulations, and testing.


* Free software: MIT license
* Documentation: https://phypy.readthedocs.io.


Features
--------

* A power amplifier model with realistic coefficients extracted from a WARPv3 board PA.


Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
